@@ -8,13 +8,6 @@ import logging
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 from concurrent.futures import ThreadPoolExecutor, as_completed
-from sqlalchemy.types import VARCHAR
-from sqlalchemy.types import DateTime
-from sqlalchemy import MetaData,Column, Table
-from sqlalchemy.orm import sessionmaker, mapper
-from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.schema import Index
-from threading import Thread
 
 
 import re
