@@ -5,10 +5,7 @@ import logging
 import pandas as pd
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
-from typing import TYPE_CHECKING
 from IPython.display import Image, display, HTML
-if TYPE_CHECKING:
-    from askdata.askdata_client import Askdata
 
 _LOG_FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s() ] - %(asctime)s --> %(message)s"
 g_logger = logging.getLogger()
@@ -244,7 +241,6 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         self.components = r.json()["components"]
@@ -339,24 +335,10 @@ class Insight_Definition:
 
     def add_chart(self, type:str, query:str, params:list, title = "Chart"):
         position = (len(self.components))
-        body = {"type": "chart", "position": position}
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
+        chart_id = self.add_component("chart", position)
 
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        #logging.info("URL {}".format(query_url))
-        r = s.post(url=query_url, json=body, headers=headers)
-        r.raise_for_status()
-        self.components = r.json()["components"]
-
-        self.edit_chart(self.components[position]["id"], type, query, params, title)
+        self.edit_chart(chart_id, type, query, params, title)
 
 
         return self.components[position]["id"]
